@@ -156,6 +156,7 @@ class Build(HeadersMixin):
     uid = attrib(default=None)
     json = attrib(default=False)
     limit = attrib(default=0)
+    no_cache = attrib(default=False)
 
     def __attrs_post_init__(self):
         if isinstance(self.kconfig, str):
@@ -213,6 +214,8 @@ class Build(HeadersMixin):
             build_entry["plan"] = plan
         if self.image_sha:
             build_entry["image_sha"] = self.image_sha
+        if self.no_cache:
+            build_entry["no_cache"] = self.no_cache
         if self.patch_series:
             (
                 build_entry["kernel_patch_file"],
